==> walkers-fabric-1.18.2-4.5-sources.jar: tocraft/walkers/ability/impl/GhastAbility.java <==
package tocraft.walkers.ability.impl;

import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1674;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import tocraft.walkers.ability.ShapeAbility;

public class GhastAbility<T extends class_1308> extends ShapeAbility<T> {

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1674 fireball = new class_1674(
                world,
                player,
                player.method_5720().field_1352,
                player.method_5720().field_1351,
                player.method_5720().field_1350,
                2
        );

        fireball.method_5808(fireball.method_23317(), fireball.method_23318() + 1.75, fireball.method_23321(), fireball.method_36454(), fireball.method_36455());
        fireball.method_30634(fireball.method_23317(), fireball.method_23318(), fireball.method_23321());
        world.method_8649(fireball);
        world.method_8449(null, player, class_3417.field_15231, class_3419.field_15251, 10.0F, (world.field_9229.nextFloat() - world.field_9229.nextFloat()) * 0.2F + 1.0F);
        world.method_8449(null, player, class_3417.field_15130, class_3419.field_15251, 10.0F, (world.field_9229.nextFloat() - world.field_9229.nextFloat()) * 0.2F + 1.0F);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8814;
    }

    @Override
    public int getDefaultCooldown() {
        return 60;
    }
}

==> walkers-fabric-1.20.2-4.4.1-sources.jar: tocraft/walkers/ability/impl/GhastAbility.java <==
package tocraft.walkers.ability.impl;

import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1674;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import tocraft.walkers.ability.ShapeAbility;

public class GhastAbility<T extends class_1308> extends ShapeAbility<T> {

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1674 fireball = new class_1674(
                world,
                player,
                player.method_5720().field_1352,
                player.method_5720().field_1351,
                player.method_5720().field_1350,
                2
        );

        fireball.method_5808(fireball.method_23317(), fireball.method_23318() + 1.75, fireball.method_23321(), fireball.method_36454(), fireball.method_36455());
        fireball.method_30634(fireball.method_23317(), fireball.method_23318(), fireball.method_23321());
        world.method_8649(fireball);
        world.method_43129(null, player, class_3417.field_15231, class_3419.field_15251, 10.0F, (world.field_9229.method_43057() - world.field_9229.method_43057()) * 0.2F + 1.0F);
        world.method_43129(null, player, class_3417.field_15130, class_3419.field_15251, 10.0F, (world.field_9229.method_43057() - world.field_9229.method_43057()) * 0.2F + 1.0F);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8814;
    }

    @Override
    public int getDefaultCooldown() {
        return 60;
    }
}
